@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,6 @@
 #include "folder/foldersettings.h"
 #include "folderrequester.h"
 #include "kernel/mailkernel.h"
-#include "mailcommon_debug.h"
 #include "util/mailutil.h"
 
 #include <Akonadi/CollectionModifyJob>
@@ -37,7 +36,7 @@ public:
         setSpecialValueText(i18n("Never"));
     }
 
-    Q_REQUIRED_RESULT QString textFromValue(int value) const override
+    [[nodiscard]] QString textFromValue(int value) const override
     {
         if (value == 0) {
             return i18n("Never");
@@ -45,7 +44,7 @@ public:
         return KPluralHandlingSpinBox::textFromValue(value);
     }
 
-    Q_REQUIRED_RESULT int valueFromText(const QString &text) const override
+    [[nodiscard]] int valueFromText(const QString &text) const override
     {
         return KPluralHandlingSpinBox::valueFromText(text);
     }
@@ -278,3 +277,5 @@ QDebug operator<<(QDebug d, const CollectionExpirySettings &t)
     d << " mExpireToFolderId " << t.mExpireToFolderId;
     return d;
 }
+
+#include "moc_collectionexpirywidget.cpp"
