@@ -40,7 +40,7 @@ using namespace MailCommon;
 CollectionGeneralPage::CollectionGeneralPage(QWidget *parent)
     : CollectionPropertiesPage(parent)
 {
-    setObjectName(QStringLiteral("MailCommon::CollectionGeneralPage"));
+    setObjectName(QLatin1StringView("MailCommon::CollectionGeneralPage"));
     setPageTitle(i18nc("@title:tab General settings for a folder.", "General"));
 }
 
