@@ -21,7 +21,7 @@ namespace PimCommon
 class IncidencesForWidget;
 class ContentTypeWidget;
 }
-namespace KIdentityManagement
+namespace KIdentityManagementCore
 {
 }
 namespace MailCommon
@@ -47,8 +47,8 @@ protected:
     void init(const Akonadi::Collection &);
 
 private:
-    void slotFolderContentsSelectionChanged(int);
-    void slotNameChanged(const QString &name);
+    MAILCOMMON_NO_EXPORT void slotFolderContentsSelectionChanged(int);
+    MAILCOMMON_NO_EXPORT void slotNameChanged(const QString &name);
 
 private:
     QString mColorName;
