@@ -25,15 +25,17 @@ void FilterActionMissingTemplateDialogTest::shouldHaveDefaultValue()
     MailCommon::FilterActionMissingTemplateDialog dlg(QStringList(), QStringLiteral("filename"));
     QVERIFY(!dlg.windowTitle().isEmpty());
 
-    auto *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 
-    auto *label = dlg.findChild<QLabel *>(QStringLiteral("label"));
+    auto label = dlg.findChild<QLabel *>(QStringLiteral("label"));
     QVERIFY(label);
     QVERIFY(!label->text().isEmpty());
 
-    auto *mComboBoxTemplate = dlg.findChild<QComboBox *>(QStringLiteral("comboboxtemplate"));
+    auto mComboBoxTemplate = dlg.findChild<QComboBox *>(QStringLiteral("comboboxtemplate"));
     QVERIFY(mComboBoxTemplate);
 }
 
 QTEST_MAIN(FilterActionMissingTemplateDialogTest)
+
+#include "moc_filteractionmissingtemplatedialogtest.cpp"
