@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -14,9 +14,7 @@ FilterActionRemoveHeaderTest::FilterActionRemoveHeaderTest(QObject *parent)
 {
 }
 
-FilterActionRemoveHeaderTest::~FilterActionRemoveHeaderTest()
-{
-}
+FilterActionRemoveHeaderTest::~FilterActionRemoveHeaderTest() = default;
 
 void FilterActionRemoveHeaderTest::shouldHaveDefaultValue()
 {
@@ -163,3 +161,5 @@ void FilterActionRemoveHeaderTest::shouldHaveRequiredPart()
 }
 
 QTEST_MAIN(FilterActionRemoveHeaderTest)
+
+#include "moc_filteractionremoveheadertest.cpp"
