@@ -1,22 +1,20 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filteractionsendfakedispositiontest.h"
 #include "../filteractions/filteractionsendfakedisposition.h"
-#include <QTest>
 #include <QComboBox>
+#include <QTest>
 
 FilterActionSendFakeDispositionTest::FilterActionSendFakeDispositionTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-FilterActionSendFakeDispositionTest::~FilterActionSendFakeDispositionTest()
-{
-}
+FilterActionSendFakeDispositionTest::~FilterActionSendFakeDispositionTest() = default;
 
 void FilterActionSendFakeDispositionTest::shouldHaveDefaultValue()
 {
@@ -43,3 +41,5 @@ void FilterActionSendFakeDispositionTest::shouldHaveRequiredPart()
 }
 
 QTEST_MAIN(FilterActionSendFakeDispositionTest)
+
+#include "moc_filteractionsendfakedispositiontest.cpp"
