@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -23,7 +23,7 @@ public:
         return GoOn;
     }
 
-    Q_REQUIRED_RESULT MailCommon::SearchRule::RequiredPart requiredPart() const override
+    [[nodiscard]] MailCommon::SearchRule::RequiredPart requiredPart() const override
     {
         return MailCommon::SearchRule::CompleteMessage;
     }
@@ -41,7 +41,7 @@ void FilterActionWithAddressTest::shouldHaveDefaultValue()
     TestFilterActionWithAddress filter;
     QWidget *w = filter.createParamWidget(nullptr);
     QCOMPARE(w->objectName(), QStringLiteral("emailaddressrequester"));
-    auto *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
+    auto requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
     QVERIFY(requester);
     QVERIFY(filter.isEmpty());
 }
@@ -50,7 +50,7 @@ void FilterActionWithAddressTest::shouldAssignValue()
 {
     TestFilterActionWithAddress filter;
     QWidget *w = filter.createParamWidget(nullptr);
-    auto *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
+    auto requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
     filter.argsFromString(QStringLiteral("foo"));
     filter.setParamWidgetValue(w);
     QVERIFY(!filter.isEmpty());
@@ -64,3 +64,5 @@ void FilterActionWithAddressTest::shouldRequiresPart()
 }
 
 QTEST_MAIN(FilterActionWithAddressTest)
+
+#include "moc_filteractionwithaddresstest.cpp"
