@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,30 +7,28 @@
 #include "filterconverttosieveresultdialogtest.h"
 #include "../filterconverter/filterconverttosieveresultdialog.h"
 #include <QDialogButtonBox>
-#include <QTest>
 #include <QPushButton>
-#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <QStandardPaths>
+#include <QTest>
+#include <TextCustomEditor/PlainTextEditorWidget>
 FilterConvertToSieveResultDialogTest::FilterConvertToSieveResultDialogTest(QObject *parent)
     : QObject(parent)
 {
     QStandardPaths::setTestModeEnabled(true);
 }
 
-FilterConvertToSieveResultDialogTest::~FilterConvertToSieveResultDialogTest()
-{
-}
+FilterConvertToSieveResultDialogTest::~FilterConvertToSieveResultDialogTest() = default;
 
 void FilterConvertToSieveResultDialogTest::shouldHaveDefaultValue()
 {
     MailCommon::FilterConvertToSieveResultDialog dlg;
-    auto *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 
-    auto *saveButton = dlg.findChild<QPushButton *>(QStringLiteral("savebutton"));
+    auto saveButton = dlg.findChild<QPushButton *>(QStringLiteral("savebutton"));
     QVERIFY(saveButton);
 
-    auto *editor = dlg.findChild<KPIMTextEdit::PlainTextEditorWidget *>(QStringLiteral("editor"));
+    auto editor = dlg.findChild<TextCustomEditor::PlainTextEditorWidget *>(QStringLiteral("editor"));
     QVERIFY(editor);
     QVERIFY(editor->toPlainText().isEmpty());
 }
@@ -39,7 +37,7 @@ void FilterConvertToSieveResultDialogTest::shouldAddCode()
 {
     MailCommon::FilterConvertToSieveResultDialog dlg;
 
-    auto *editor = dlg.findChild<KPIMTextEdit::PlainTextEditorWidget *>(QStringLiteral("editor"));
+    auto editor = dlg.findChild<TextCustomEditor::PlainTextEditorWidget *>(QStringLiteral("editor"));
     QVERIFY(editor->toPlainText().isEmpty());
     const QString code = QStringLiteral("foo");
     dlg.setCode(code);
@@ -47,3 +45,5 @@ void FilterConvertToSieveResultDialogTest::shouldAddCode()
 }
 
 QTEST_MAIN(FilterConvertToSieveResultDialogTest)
+
+#include "moc_filterconverttosieveresultdialogtest.cpp"
