@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterimporterpathcachetest.h"
 #include "../filterimporterpathcache.h"
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 #include <QTest>
 
 QTEST_MAIN(FilterImporterPathCacheTest)
@@ -16,9 +16,7 @@ FilterImporterPathCacheTest::FilterImporterPathCacheTest(QObject *parent)
 {
 }
 
-FilterImporterPathCacheTest::~FilterImporterPathCacheTest()
-{
-}
+FilterImporterPathCacheTest::~FilterImporterPathCacheTest() = default;
 
 void FilterImporterPathCacheTest::shouldReturnEmptyStringWhenListIsEmpty()
 {
@@ -77,3 +75,5 @@ void FilterImporterPathCacheTest::shouldReturnValues()
     cache.insert(key, cached);
     QCOMPARE(cache.convertedFilterPath(key), cached);
 }
+
+#include "moc_filterimporterpathcachetest.cpp"
