@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -25,7 +25,7 @@ void InvalidFilterListWidgetTest::shouldHaveDefaultValue()
 void InvalidFilterListWidgetTest::shouldAddInvalidFilters()
 {
     MailCommon::InvalidFilterListView w;
-    QVector<MailCommon::InvalidFilterInfo> lst;
+    QList<MailCommon::InvalidFilterInfo> lst;
     lst.append(MailCommon::InvalidFilterInfo(QStringLiteral("foo"), QStringLiteral("bla")));
     lst.append(MailCommon::InvalidFilterInfo(QStringLiteral("foo1"), QStringLiteral("bla1")));
     lst.append(MailCommon::InvalidFilterInfo(QStringLiteral("foo2"), QStringLiteral("bla2")));
@@ -34,3 +34,5 @@ void InvalidFilterListWidgetTest::shouldAddInvalidFilters()
 }
 
 QTEST_MAIN(InvalidFilterListWidgetTest)
+
+#include "moc_invalidfilterlistwidgettest.cpp"
