@@ -19,11 +19,13 @@ InvalidFilterWidgetTest::~InvalidFilterWidgetTest() = default;
 void InvalidFilterWidgetTest::shouldHaveDefaultValue()
 {
     MailCommon::InvalidFilterWidget w;
-    auto *lab = w.findChild<QLabel *>(QStringLiteral("label"));
+    auto lab = w.findChild<QLabel *>(QStringLiteral("label"));
     QVERIFY(lab);
 
-    auto *list = w.findChild<MailCommon::InvalidFilterListView *>(QStringLiteral("invalidfilterlist"));
+    auto list = w.findChild<MailCommon::InvalidFilterListView *>(QStringLiteral("invalidfilterlist"));
     QVERIFY(list);
 }
 
 QTEST_MAIN(InvalidFilterWidgetTest)
+
+#include "moc_invalidfilterwidgettest.cpp"
