@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,12 +16,12 @@ class FilterActionMissingAccountDialog : public QDialog
 public:
     explicit FilterActionMissingAccountDialog(const QStringList &lstAccount, const QString &filtername, QWidget *parent = nullptr);
     ~FilterActionMissingAccountDialog() override;
-    Q_REQUIRED_RESULT QStringList selectedAccount() const;
+    [[nodiscard]] QStringList selectedAccount() const;
     static bool allAccountExist(const QStringList &lst);
 
 private:
     void readConfig();
     void writeConfig();
-    MailCommon::KMFilterAccountList *mAccountList = nullptr;
+    MailCommon::KMFilterAccountList *const mAccountList;
 };
 }
