@@ -8,7 +8,7 @@
 
 #include <QDialog>
 
-namespace KIdentityManagement
+namespace KIdentityManagementWidgets
 {
 class IdentityCombo;
 }
@@ -20,11 +20,11 @@ class FilterActionMissingIdentityDialog : public QDialog
 public:
     explicit FilterActionMissingIdentityDialog(const QString &filtername, QWidget *parent = nullptr);
     ~FilterActionMissingIdentityDialog() override;
-    Q_REQUIRED_RESULT int selectedIdentity() const;
+    [[nodiscard]] int selectedIdentity() const;
 
 private:
     void writeConfig();
     void readConfig();
-    KIdentityManagement::IdentityCombo *mComboBoxIdentity = nullptr;
+    KIdentityManagementWidgets::IdentityCombo *mComboBoxIdentity = nullptr;
 };
 }
