@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,12 +16,11 @@ class FilterActionMissingSoundUrlDialog : public QDialog
 public:
     explicit FilterActionMissingSoundUrlDialog(const QString &filtername, const QString &argStr, QWidget *parent = nullptr);
     ~FilterActionMissingSoundUrlDialog() override;
-    Q_REQUIRED_RESULT QString soundUrl() const;
+    [[nodiscard]] QString soundUrl() const;
 
 private:
     void readConfig();
     void writeConfig();
-    KUrlRequester *mUrlWidget = nullptr;
+    KUrlRequester *const mUrlWidget;
 };
 }
-
