@@ -33,19 +33,19 @@ FilterActionMissingTemplateDialog::FilterActionMissingTemplateDialog(const QStri
     auto mainLayout = new QVBoxLayout(this);
 
     auto label = new QLabel(this);
-    label->setObjectName(QStringLiteral("label"));
+    label->setObjectName(QLatin1StringView("label"));
     label->setText(
         i18n("Filter template is missing. "
              "Please select a template to use with filter \"%1\"",
              filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
-    mComboBoxTemplate->setObjectName(QStringLiteral("comboboxtemplate"));
+    mComboBoxTemplate->setObjectName(QLatin1StringView("comboboxtemplate"));
     mComboBoxTemplate->addItems(templateList);
     mainLayout->addWidget(mComboBoxTemplate);
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
-    buttonBox->setObjectName(QStringLiteral("buttonbox"));
+    buttonBox->setObjectName(QLatin1StringView("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
