@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,11 +17,11 @@ class FilterActionMissingTemplateDialog : public QDialog
 public:
     explicit FilterActionMissingTemplateDialog(const QStringList &templateList, const QString &filtername, QWidget *parent = nullptr);
     ~FilterActionMissingTemplateDialog() override;
-    Q_REQUIRED_RESULT QString selectedTemplate() const;
+    [[nodiscard]] QString selectedTemplate() const;
 
 private:
     void readConfig();
     void writeConfig();
-    QComboBox *mComboBoxTemplate = nullptr;
+    QComboBox *const mComboBoxTemplate;
 };
 }
