@@ -113,6 +113,8 @@ QStringList SelectThunderbirdFilterFilesWidget::selectedFiles() const
 
 void SelectThunderbirdFilterFilesWidget::setStartDir(const QUrl &url)
 {
-    ui->fileUrl->setFilter(QStringLiteral("*.dat"));
+    ui->fileUrl->setNameFilter(i18n("Thunderbird File (*.dat)"));
     ui->fileUrl->setStartDir(url);
 }
+
+#include "moc_selectthunderbirdfilterfileswidget.cpp"
