@@ -20,22 +20,22 @@ class FilterActionAddToAddressBook : public FilterActionWithStringList
     Q_OBJECT
 public:
     explicit FilterActionAddToAddressBook(QObject *parent = nullptr);
-    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    [[nodiscard]] ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
     static FilterAction *newAction();
 
-    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
+    [[nodiscard]] SearchRule::RequiredPart requiredPart() const override;
 
-    Q_REQUIRED_RESULT bool isEmpty() const override;
+    [[nodiscard]] bool isEmpty() const override;
 
-    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
+    [[nodiscard]] QWidget *createParamWidget(QWidget *parent) const override;
     void setParamWidgetValue(QWidget *paramWidget) const override;
     void applyParamWidgetValue(QWidget *paramWidget) override;
     void clearParamWidget(QWidget *paramWidget) const override;
 
-    Q_REQUIRED_RESULT QString argsAsString() const override;
+    [[nodiscard]] QString argsAsString() const override;
     void argsFromString(const QString &argsStr) override;
 
-    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
+    [[nodiscard]] QString informationAboutNotValidAction() const override;
 
 private:
     enum HeaderType { FromHeader, ToHeader, CcHeader, BccHeader, UnknownHeader };
