@@ -7,7 +7,7 @@
 
 #include "filteractionsendfakedisposition.h"
 
-#include "mailcommon/mdnstateattribute.h"
+#include <Akonadi/MDNStateAttribute>
 #include <KLocalizedString>
 
 using namespace MailCommon;
@@ -60,8 +60,8 @@ FilterAction::ReturnCode FilterActionSendFakeDisposition::process(ItemContext &c
     }
 
     if (index == 1) { // ignore
-        if (context.item().hasAttribute<MailCommon::MDNStateAttribute>()) {
-            context.item().attribute<MailCommon::MDNStateAttribute>()->setMDNState(MailCommon::MDNStateAttribute::MDNIgnore);
+        if (context.item().hasAttribute<Akonadi::MDNStateAttribute>()) {
+            context.item().attribute<Akonadi::MDNStateAttribute>()->setMDNState(Akonadi::MDNStateAttribute::MDNIgnore);
             context.setNeedsFlagStore();
         }
     } else { // send
@@ -99,10 +99,10 @@ QString FilterActionSendFakeDisposition::argsAsString() const
 {
     const int index = mParameterList.indexOf(mParameter);
     if (index < 1) {
-        return QString();
+        return {};
     }
 
-    return QString(QChar(index < 2 ? 'I' : char(mdns[index - 2])));
+    return {QChar(index < 2 ? 'I' : char(mdns[index - 2]))};
 }
 
 QString FilterActionSendFakeDisposition::displayString() const
@@ -114,3 +114,5 @@ QString FilterActionSendFakeDisposition::informationAboutNotValidAction() const
 {
     return i18n("Fake type undefined.");
 }
+
+#include "moc_filteractionsendfakedisposition.cpp"
