@@ -27,7 +27,7 @@ QWidget *FilterActionWithTest::createParamWidget(QWidget *parent) const
 {
     auto soundWidget = new SoundTestWidget(parent);
     soundWidget->setUrl(mParameter);
-    soundWidget->setObjectName(QStringLiteral("soundwidget"));
+    soundWidget->setObjectName(QLatin1StringView("soundwidget"));
 
     connect(soundWidget, &SoundTestWidget::textChanged, this, &FilterActionWithTest::filterActionModified);
 
