@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #pragma once
 
-#include <QVector>
+#include <QList>
 
 namespace MailCommon
 {
@@ -14,12 +14,12 @@ class MailFilter;
 class FilterConvertToSieve
 {
 public:
-    FilterConvertToSieve(const QVector<MailFilter *> &filters);
+    FilterConvertToSieve(const QList<MailFilter *> &filters);
     ~FilterConvertToSieve();
 
     void convert();
 
 private:
-    const QVector<MailFilter *> mListFilters;
+    const QList<MailFilter *> mListFilters;
 };
 }
