@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 #include "filterimportevolutiontest.h"
 #include "filter/mailfilter.h"
 #include "filtertestkernel.h"
-#include <AkonadiCore/qtest_akonadi.h>
 #include <MailCommon/MailKernel>
+#include <akonadi/qtest_akonadi.h>
 
 void FilterImportEvolutiontest::initTestCase()
 {
@@ -23,3 +23,5 @@ void FilterImportEvolutiontest::testImportFilters()
 }
 
 QTEST_AKONADIMAIN(FilterImportEvolutiontest)
+
+#include "moc_filterimportevolutiontest.cpp"
