@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #pragma once
 
 #include "mailcommon_export.h"
+#include <QList>
 #include <QStringList>
-#include <QVector>
 
 class QFile;
 class QDomDocument;
@@ -22,15 +22,15 @@ class MAILCOMMON_EXPORT FilterImporterAbstract
 public:
     explicit FilterImporterAbstract(bool interactive = true);
     ~FilterImporterAbstract();
-    Q_REQUIRED_RESULT QVector<MailFilter *> importFilter() const;
-    Q_REQUIRED_RESULT QStringList emptyFilter() const;
+    [[nodiscard]] QList<MailFilter *> importFilter() const;
+    [[nodiscard]] QStringList emptyFilter() const;
 
 protected:
     void appendFilter(MailCommon::MailFilter *filter);
     void createFilterAction(MailCommon::MailFilter *filter, const QString &actionName, const QString &value);
     bool loadDomElement(QDomDocument &doc, QFile *file);
 
-    QVector<MailFilter *> mListMailFilter;
+    QList<MailFilter *> mListMailFilter;
     QStringList mEmptyFilter;
 
 private:
