@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,9 @@ public:
     static QString defaultFiltersSettingsPath();
 
 private:
-    Q_REQUIRED_RESULT MailCommon::MailFilter *parseLine(QTextStream &stream, QString line, MailCommon::MailFilter *filter);
+    [[nodiscard]] MailCommon::MailFilter *parseLine(QTextStream &stream, QString line, MailCommon::MailFilter *filter);
     void readStream(QTextStream &stream);
-    Q_REQUIRED_RESULT QString createUniqFilterName();
+    [[nodiscard]] QString createUniqFilterName();
     int mFilterCount = 0;
 };
 }
