@@ -107,7 +107,7 @@ FilterManager::FilterManager()
 {
     updateTagList();
 
-    d->mMonitor->setObjectName(QStringLiteral("FilterManagerTagMonitor"));
+    d->mMonitor->setObjectName(QLatin1StringView("FilterManagerTagMonitor"));
     d->mMonitor->setTypeMonitored(Akonadi::Monitor::Tags);
     d->mMonitor->tagFetchScope().fetchAttribute<Akonadi::TagAttribute>();
     connect(d->mMonitor, &Akonadi::Monitor::tagAdded, this, &FilterManager::slotTagAdded);
