@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -324,21 +324,21 @@ void KMFilterListBox::applyFilterChanged(bool closeAfterSaving)
     // their widget's data into our filter list.
 
     bool wasCanceled = false;
-    const QVector<MailFilter *> newFilters = filtersForSaving(closeAfterSaving, wasCanceled);
+    const QList<MailFilter *> newFilters = filtersForSaving(closeAfterSaving, wasCanceled);
     if (!wasCanceled) {
         MailCommon::FilterManager::instance()->setFilters(newFilters);
     }
 }
 
-QVector<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, bool &wasCanceled) const
+QList<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, bool &wasCanceled) const
 {
     Q_EMIT const_cast<KMFilterListBox *>(this)->applyWidgets(); // signals aren't const
-    QVector<MailFilter *> filters;
+    QList<MailFilter *> filters;
     QStringList emptyFilters;
-    QVector<MailCommon::InvalidFilterInfo> listInvalidFilters;
+    QList<MailCommon::InvalidFilterInfo> listInvalidFilters;
     const int numberOfFilter(mListWidget->count());
     for (int i = 0; i < numberOfFilter; ++i) {
-        auto *itemFilter = static_cast<QListWidgetFilterItem *>(mListWidget->item(i));
+        auto itemFilter = static_cast<QListWidgetFilterItem *>(mListWidget->item(i));
         auto f = new MailFilter(*itemFilter->filter()); // deep copy
 
         const QString information = f->purify();
@@ -379,7 +379,7 @@ void KMFilterListBox::slotSelectionChanged()
 void KMFilterListBox::slotSelected(int aIdx)
 {
     if (aIdx >= 0 && aIdx < mListWidget->count()) {
-        auto *itemFilter = static_cast<QListWidgetFilterItem *>(mListWidget->item(aIdx));
+        auto itemFilter = static_cast<QListWidgetFilterItem *>(mListWidget->item(aIdx));
         MailFilter *f = itemFilter->filter();
 
         if (f) {
@@ -443,13 +443,13 @@ void KMFilterListBox::slotDelete()
     const QString question =
         uniqFilterSelected ? i18n("Do you want to remove the filter \"%1\"?", filter->pattern()->name()) : i18n("Do you want to remove selected filters?");
     const QString dialogTitle = uniqFilterSelected ? i18n("Remove Filter") : i18n("Remove Filters");
-    const int answer = KMessageBox::questionYesNo(this, question, dialogTitle, KStandardGuiItem::remove(), KStandardGuiItem::cancel());
-    if (answer == KMessageBox::No) {
+    const int answer = KMessageBox::questionTwoActions(this, question, dialogTitle, KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+    if (answer == KMessageBox::ButtonCode::SecondaryAction) {
         return;
     }
 
     const int oIdxSelItem = mListWidget->currentRow();
-    QVector<MailCommon::MailFilter *> lst;
+    QList<MailCommon::MailFilter *> lst;
 
     Q_EMIT resetWidgets();
 
@@ -722,9 +722,9 @@ void KMFilterListBox::loadFilterList(bool createDummyFilter)
     // clear both lists
     mListWidget->clear();
 
-    const QVector<MailFilter *> filters = MailCommon::FilterManager::instance()->filters();
+    const QList<MailFilter *> filters = MailCommon::FilterManager::instance()->filters();
     for (MailFilter *filter : filters) {
-        auto *item = new QListWidgetFilterItem(filter->pattern()->name(), mListWidget);
+        auto item = new QListWidgetFilterItem(filter->pattern()->name(), mListWidget);
         item->setFilter(new MailFilter(*filter));
         mListWidget->addItem(item);
     }
@@ -770,7 +770,7 @@ void KMFilterListBox::insertFilter(MailFilter *aFilter)
 
 void KMFilterListBox::appendFilter(MailFilter *aFilter)
 {
-    auto *item = new QListWidgetFilterItem(aFilter->pattern()->name(), mListWidget);
+    auto item = new QListWidgetFilterItem(aFilter->pattern()->name(), mListWidget);
 
     item->setFilter(aFilter);
     mListWidget->addItem(item);
@@ -811,3 +811,5 @@ MailCommon::MailFilter *QListWidgetFilterItem::filter() const
 {
     return mFilter;
 }
+
+#include "moc_kmfilterlistbox.cpp"
