@@ -76,7 +76,7 @@ void FilterImporterExporterGui::importFilters(MailCommon::FilterImporterExporter
 {
     MailCommon::FilterImporterExporter importer(this);
     bool canceled = false;
-    const QVector<MailCommon::MailFilter *> filters = importer.importFilters(canceled, type);
+    const QList<MailCommon::MailFilter *> filters = importer.importFilters(canceled, type);
     if (canceled) {
         mTextEdit->setText(QStringLiteral("Canceled"));
         return;
@@ -102,3 +102,5 @@ int main(int argc, char **argv)
     delete w;
     return 0;
 }
+
+#include "moc_filterimporterexportergui.cpp"
