@@ -38,7 +38,7 @@ public:
     explicit FolderCollectionMonitor(Akonadi::Session *session, QObject *parent = nullptr);
     ~FolderCollectionMonitor() override;
 
-    Q_REQUIRED_RESULT Akonadi::ChangeRecorder *monitor() const;
+    [[nodiscard]] Akonadi::ChangeRecorder *monitor() const;
     void expireAllFolders(bool immediate, QAbstractItemModel *collectionModel);
     void expunge(const Akonadi::Collection &, bool sync = false);
 
