@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2004 Carsten Burghardt <burghardt@kde.org>
- * SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-only
  */
@@ -10,7 +10,7 @@
 #include "kernel/mailkernel.h"
 #include "util/mailutil.h"
 #include <Akonadi/CollectionFetchJob>
-#include <Libkdepim/LineEditCatchReturnKey>
+#include <KLineEditEventHandler>
 
 #include <KLocalizedString>
 #include <QIcon>
@@ -43,7 +43,7 @@ FolderRequester::FolderRequester(QWidget *parent)
 
     d->mEdit = new QLineEdit(this);
     d->mEdit->setPlaceholderText(i18n("Select Folder"));
-    new KPIM::LineEditCatchReturnKey(d->mEdit, this);
+    KLineEditEventHandler::catchReturnKey(d->mEdit);
     d->mEdit->setReadOnly(true);
     hlay->addWidget(d->mEdit);
 
@@ -103,7 +103,7 @@ void FolderRequester::setCollection(const Akonadi::Collection &collection, bool
     d->mCollection = collection;
     if (d->mCollection.isValid()) {
         if (fetchCollection) {
-            auto *job = new Akonadi::CollectionFetchJob(d->mCollection, Akonadi::CollectionFetchJob::Base, this);
+            auto job = new Akonadi::CollectionFetchJob(d->mCollection, Akonadi::CollectionFetchJob::Base, this);
 
             connect(job, &Akonadi::CollectionFetchJob::result, this, &FolderRequester::slotCollectionsReceived);
         } else {
@@ -177,3 +177,5 @@ void FolderRequester::setSelectFolderTitleDialog(const QString &title)
 {
     d->mSelectFolderTitleDialog = title;
 }
+
+#include "moc_folderrequester.cpp"
