@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -14,13 +14,11 @@ SnippetsManagerTest::SnippetsManagerTest(QObject *parent)
 {
 }
 
-SnippetsManagerTest::~SnippetsManagerTest()
-{
-}
+SnippetsManagerTest::~SnippetsManagerTest() = default;
 
 void SnippetsManagerTest::shouldHaveDefaultValue()
 {
-    KActionCollection *collection = new KActionCollection(this);
+    auto collection = new KActionCollection(this);
     MailCommon::SnippetsManager snippetManager(collection, this);
     QVERIFY(snippetManager.deleteSnippetAction());
     QVERIFY(snippetManager.model());
@@ -36,3 +34,5 @@ void SnippetsManagerTest::shouldHaveDefaultValue()
 }
 
 QTEST_MAIN(SnippetsManagerTest)
+
+#include "moc_snippetsmanagertest.cpp"
