@@ -19,7 +19,7 @@ public:
     ~SnippetSelectAttachmentDialog() override;
 
     void setAttachments(const QStringList &lst);
-    Q_REQUIRED_RESULT QStringList attachments() const;
+    [[nodiscard]] QStringList attachments() const;
 
 private:
     void writeConfig();
